export interface LoginDataDTO {
    username: string;
    password: string;
}
export interface LoginReturnDataDTO {
    accessToken: string;
}
export interface FileUploadDto {
    files: unknown[];
}
export interface FileDto {
    data: unknown;
}
export interface RegisterUserDTO {
    title: string;
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
    password: string;
}
export declare type UserStatus = 'Pending' | 'Active' | 'Suspended' | 'Deleted';
export declare const UserStatus: {
    Pending: UserStatus;
    Active: UserStatus;
    Suspended: UserStatus;
    Deleted: UserStatus;
};
export declare type KYCStatus = 'Pending' | 'Passed' | 'Rejected';
export declare const KYCStatus: {
    Pending: KYCStatus;
    Passed: KYCStatus;
    Rejected: KYCStatus;
};
export declare type OrganizationStatus = 'Submitted' | 'Denied' | 'Active';
export declare const OrganizationStatus: {
    Submitted: OrganizationStatus;
    Denied: OrganizationStatus;
    Active: OrganizationStatus;
};
export interface FullOrganizationInfoDTO {
    id: number;
    name: string;
    address: string;
    zipCode: string;
    city: string;
    country: string;
    businessType: string;
    tradeRegistryCompanyNumber: string;
    vatNumber: string;
    status: OrganizationStatus;
    signatoryFullName: string;
    signatoryAddress: string;
    signatoryZipCode: string;
    signatoryCity: string;
    signatoryCountry: string;
    signatoryEmail: string;
    signatoryPhoneNumber: string;
    documentIds?: string[];
    signatoryDocumentIds?: string[];
    blockchainAccountAddress?: string;
    blockchainAccountSignedMessage?: string;
}
export interface UserDTO {
    id: number;
    title: string;
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
    notifications: boolean;
    rights: number;
    status: UserStatus;
    kycStatus: KYCStatus;
    organization: FullOrganizationInfoDTO;
    emailConfirmed?: boolean;
}
export interface UpdateOwnUserSettingsDTO {
    notifications: boolean;
}
export interface UpdateUserProfileDTO {
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
}
export interface UpdatePasswordDTO {
    oldPassword: string;
    newPassword: string;
}
export interface SuccessResponseDTO {
    success: boolean;
    message?: string;
}
export interface ExternalDeviceIdTypeDTO {
    type: string;
    autogenerated?: boolean;
    required?: boolean;
}
export declare type ConfigurationDTORegions = {};
export interface ConfigurationDTO {
    countryName?: string;
    currencies?: string[];
    regions?: ConfigurationDTORegions;
    externalDeviceIdTypes?: ExternalDeviceIdTypeDTO[];
    complianceStandard?: string;
    deviceTypes?: string[][];
    gridOperators?: string[];
}
export interface PublicOrganizationInfoDTO {
    id: number;
    name: string;
    address: string;
    zipCode: string;
    city: string;
    country: string;
    businessType: string;
    tradeRegistryCompanyNumber: string;
    vatNumber: string;
    status: OrganizationStatus;
}
export declare type OrganizationInvitationStatus = 'Pending' | 'Rejected' | 'Accepted' | 'Viewed';
export declare const OrganizationInvitationStatus: {
    Pending: OrganizationInvitationStatus;
    Rejected: OrganizationInvitationStatus;
    Accepted: OrganizationInvitationStatus;
    Viewed: OrganizationInvitationStatus;
};
export interface InvitationDTO {
    id: number;
    email: string;
    role: number;
    status: OrganizationInvitationStatus;
    organization: PublicOrganizationInfoDTO;
    sender: string;
    createdAt: string;
}
export interface User {
    id: number;
    title: string;
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
    password: string;
    organization: Organization;
    rights: number;
    status: UserStatus;
    kycStatus: KYCStatus;
}
export declare type Role = 'OrganizationAdmin' | 'OrganizationDeviceManager' | 'OrganizationUser' | 'Issuer' | 'Admin' | 'SupportAgent';
export declare const Role: {
    OrganizationAdmin: Role;
    OrganizationDeviceManager: Role;
    OrganizationUser: Role;
    Issuer: Role;
    Admin: Role;
    SupportAgent: Role;
};
export interface Invitation {
    id: number;
    email: string;
    role: Role;
    status: OrganizationInvitationStatus;
    sender: string;
}
export interface Organization {
    id: number;
    name: string;
    address: string;
    zipCode: string;
    city: string;
    country: string;
    tradeRegistryCompanyNumber: string;
    vatNumber: string;
    signatoryFullName: string;
    signatoryAddress: string;
    signatoryZipCode: string;
    signatoryCity: string;
    signatoryCountry: string;
    signatoryEmail: string;
    signatoryPhoneNumber: string;
    signatoryDocumentIds: string[];
    status: OrganizationStatus;
    users: User[];
    invitations: Invitation[];
    documentIds: string[];
}
export interface NewOrganizationDTO {
    name: string;
    address: string;
    zipCode: string;
    city: string;
    country: string;
    businessType: string;
    tradeRegistryCompanyNumber: string;
    vatNumber: string;
    signatoryFullName: string;
    signatoryAddress: string;
    signatoryZipCode: string;
    signatoryCity: string;
    signatoryCountry: string;
    signatoryEmail: string;
    signatoryPhoneNumber: string;
    documentIds?: string[];
    signatoryDocumentIds?: string[];
}
export interface OrganizationUpdateDTO {
    status: OrganizationStatus;
}
export interface UpdateMemberDTO {
    role: number;
}
export interface BindBlockchainAccountDTO {
    signedMessage: string;
}
export interface InviteDTO {
    email: string;
    role: number;
}
export interface UpdateUserDTO {
    title: string;
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
    status: UserStatus;
    kycStatus: KYCStatus;
}
export interface UpdateBlockchainAccountDTO {
    address: string;
    signedMessage?: string;
}
export interface EnergyDTO {
    publicVolume: string;
    privateVolume: string;
    claimedVolume: string;
}
export interface ClaimDataDTO {
    beneficiary: string;
    location: string;
    countryCode: string;
    periodStartDate: string;
    periodEndDate: string;
    purpose: string;
}
export interface ClaimDTO {
    id: number;
    from: string;
    to: string;
    topic: string;
    value: string;
    claimData: ClaimDataDTO;
}
export declare type CertificateDTOBlockchain = {};
export interface CertificateDTO {
    id: number;
    deviceId: string;
    generationStartTime: number;
    generationEndTime: number;
    creationTime: number;
    metadata: string;
    energy: EnergyDTO;
    isOwned: boolean;
    isClaimed: boolean;
    myClaims?: ClaimDTO[];
    claims?: ClaimDTO[];
    blockchain?: CertificateDTOBlockchain;
    creationBlockHash?: string;
    issuedPrivately?: boolean;
}
export interface IssueCertificateDTO {
    to: string;
    energy: string;
    fromTime: number;
    toTime: number;
    deviceId: string;
    isPrivate?: boolean;
    metadata?: string;
}
export interface DelegatedTransferOptions {
    signature: string;
    from?: string;
}
export interface TransferCertificateDTO {
    to: string;
    delegated?: DelegatedTransferOptions;
    amount?: string;
}
export interface ClaimCertificateDTO {
    claimData?: ClaimDataDTO;
    amount?: string;
}
export declare type CertificateEventValues = {};
export interface CertificateEvent {
    name: string;
    timestamp: number;
    values: CertificateEventValues;
}
export interface BatchIssueCertificateDTO {
    to: string;
    energy: string;
    fromTime: number;
    toTime: number;
    deviceId: string;
    metadata?: string;
}
export interface CertificateIdsDTO {
    ids: number[];
}
export interface BatchCertificateTransferDTO {
    id: number;
    to: string;
    from?: string;
    amount?: string;
}
export declare type BatchCertificateClaimDTOClaimData = {};
export interface BatchCertificateClaimDTO {
    id: number;
    from?: string;
    amount?: string;
    claimData: BatchCertificateClaimDTOClaimData;
    to?: string;
}
export interface BlockchainPropertiesDTO {
    netId: number;
    registry: string;
    issuer: string;
    rpcNode: string;
    rpcNodeFallback?: string;
    privateIssuer?: string;
}
export interface FullCertificationRequestDTO {
    id: number;
    deviceId: string;
    energy: string;
    owner: string;
    fromTime: number;
    toTime: number;
    files: string[];
    created: number;
    approved: boolean;
    revoked: boolean;
    approvedDate?: string;
    revokedDate?: string;
    issuedCertificateId?: number;
    isPrivate?: boolean;
    organizationId: string;
    irecIssueRequestId?: string;
    irecAssetId?: string;
}
export interface CreateCertificationRequestDTO {
    to: string;
    energy: string;
    fromTime: number;
    toTime: number;
    deviceId: string;
    files?: string[];
    isPrivate?: boolean;
}
export interface CodeDescriptionDTO {
    code: string;
    description: string;
}
export interface CodeNameDTO {
    name: string;
    code: string;
}
export interface IrecAccountItemDto {
    code: string;
    volume: number;
    startDate: string;
    endDate: string;
    fuelType: CodeDescriptionDTO;
    deviceType: CodeDescriptionDTO;
    device: CodeNameDTO;
    deviceSupported: boolean;
    tagged: boolean;
    co2Produced: number;
    country: string;
    product: string;
    asset: string;
}
export interface ImportIrecCertificateDTO {
    assetId: string;
}
export interface ExternalDeviceIdDTO {
    id: string;
    type: string;
}
export interface OriginDeviceDTO {
    externalRegistryId: string;
    smartMeterId: string;
    description: string;
    externalDeviceIds?: ExternalDeviceIdDTO[];
    imageIds?: string[];
    id: string;
    owner: string;
}
export interface NewDeviceDTO {
    externalRegistryId: string;
    smartMeterId: string;
    description: string;
    externalDeviceIds?: ExternalDeviceIdDTO[];
    imageIds?: string[];
}
export declare type DeviceState = 'Draft' | 'In-progress' | 'Rejected' | 'Approved' | 'Submitted';
export declare const DeviceState: {
    Draft: DeviceState;
    Inprogress: DeviceState;
    Rejected: DeviceState;
    Approved: DeviceState;
    Submitted: DeviceState;
};
export interface PublicDeviceDTO {
    code: string;
    name: string;
    deviceType: string;
    fuelType: string;
    countryCode: string;
    registrantOrganization: string;
    issuer: string;
    capacity: string;
    commissioningDate: string;
    registrationDate: string;
    address: string;
    latitude: string;
    longitude: string;
    notes: string;
    status: DeviceState;
    id: string;
    ownerId: string;
    timezone: string;
    gridOperator: string;
    postalCode: string;
    region: string;
    subregion: string;
}
export interface DeviceDTO {
    code: string;
    name: string;
    defaultAccount: string;
    deviceType: string;
    fuelType: string;
    countryCode: string;
    registrantOrganization: string;
    issuer: string;
    capacity: string;
    commissioningDate: string;
    registrationDate: string;
    address: string;
    latitude: string;
    longitude: string;
    notes: string;
    status: DeviceState;
    id: string;
    ownerId: string;
    timezone: string;
    gridOperator: string;
    postalCode: string;
    region: string;
    subregion: string;
}
export interface CreateDeviceDTO {
    name: string;
    deviceType: string;
    fuelType: string;
    countryCode: string;
    capacity: string;
    commissioningDate: string;
    registrationDate: string;
    address: string;
    latitude: string;
    longitude: string;
    notes: string;
    timezone: string;
    gridOperator: string;
    postalCode: string;
    region: string;
    subregion: string;
}
export interface UpdateDeviceDTO {
    name: string;
    deviceType: string;
    fuelType: string;
    countryCode: string;
    capacity: string;
    commissioningDate: string;
    registrationDate: string;
    address: string;
    latitude: string;
    longitude: string;
    notes: string;
    active: boolean;
}
export interface IrecDeviceDTO {
    code: string;
    name: string;
    defaultAccount: string;
    deviceType: string;
    fuelType: string;
    countryCode: string;
    registrantOrganization: string;
    issuer: string;
    capacity: string;
    commissioningDate: string;
    registrationDate: string;
    address: string;
    latitude: string;
    longitude: string;
    notes: string;
    status: DeviceState;
}
export interface ImportIrecDeviceDTO {
    code: string;
    timezone: string;
    gridOperator: string;
    postalCode: string;
    region: string;
    subregion: string;
}
export interface UpdateDeviceStateDTO {
    status: DeviceState;
}
export interface CreateConnectionDTO {
    userName: string;
    password: string;
    clientId: string;
    clientSecret: string;
}
export interface ShortConnectionDTO {
    expiryDate: string;
    userName: string;
    clientId: string;
    active: boolean;
}
export interface AccountDetailsDTO {
    name: string;
    private: boolean;
    restricted: boolean;
    active: boolean;
    notes: string;
    countryCode: string;
}
export declare type AccountDTOType = 'Trade' | 'Redemption' | 'Issue';
export declare const AccountDTOType: {
    Trade: AccountDTOType;
    Redemption: AccountDTOType;
    Issue: AccountDTOType;
};
export interface AccountDTO {
    code: string;
    type: AccountDTOType;
    details: AccountDetailsDTO;
}
export declare type IRECAccountType = 'Registrant' | 'Participant' | 'Both';
export declare const IRECAccountType: {
    Registrant: IRECAccountType;
    Participant: IRECAccountType;
    Both: IRECAccountType;
};
export interface RegistrationDTO {
    accountType: IRECAccountType;
    headquarterCountry: string;
    registrationYear: number;
    employeesNumber: string;
    shareholders: string;
    website: string;
    activeCountries: string[];
    mainBusiness: string;
    ceoName: string;
    ceoPassportNumber: string;
    balanceSheetTotal: string;
    subsidiaries?: string;
    primaryContactOrganizationName: string;
    primaryContactOrganizationAddress: string;
    primaryContactOrganizationPostalCode: string;
    primaryContactOrganizationCountry: string;
    primaryContactName: string;
    primaryContactEmail: string;
    primaryContactPhoneNumber: string;
    primaryContactFax: string;
    leadUserTitle: string;
    leadUserFirstName: string;
    leadUserLastName: string;
    leadUserEmail: string;
    leadUserPhoneNumber: string;
    leadUserFax: string;
    id: string;
    owner: string;
}
export interface NewRegistrationDTO {
    accountType: IRECAccountType;
    headquarterCountry: string;
    registrationYear: number;
    employeesNumber: string;
    shareholders: string;
    website: string;
    activeCountries: string[];
    mainBusiness: string;
    ceoName: string;
    ceoPassportNumber: string;
    balanceSheetTotal: string;
    subsidiaries?: string;
    primaryContactOrganizationName: string;
    primaryContactOrganizationAddress: string;
    primaryContactOrganizationPostalCode: string;
    primaryContactOrganizationCountry: string;
    primaryContactName: string;
    primaryContactEmail: string;
    primaryContactPhoneNumber: string;
    primaryContactFax: string;
    leadUserTitle: string;
    leadUserFirstName: string;
    leadUserLastName: string;
    leadUserEmail: string;
    leadUserPhoneNumber: string;
    leadUserFax: string;
}
export interface RegisterResponseDTO {
    id: string;
}
export declare type AdminControllerGetUsersParams = {
    orgName?: string;
    status?: AdminControllerGetUsersStatus;
    kycStatus?: AdminControllerGetUsersKycStatus;
};
export declare type AdminControllerGetUsersStatus = 'Pending' | 'Active' | 'Suspended' | 'Deleted';
export declare const AdminControllerGetUsersStatus: {
    Pending: AdminControllerGetUsersStatus;
    Active: AdminControllerGetUsersStatus;
    Suspended: AdminControllerGetUsersStatus;
    Deleted: AdminControllerGetUsersStatus;
};
export declare type AdminControllerGetUsersKycStatus = 'Pending' | 'Passed' | 'Rejected';
export declare const AdminControllerGetUsersKycStatus: {
    Pending: AdminControllerGetUsersKycStatus;
    Passed: AdminControllerGetUsersKycStatus;
    Rejected: AdminControllerGetUsersKycStatus;
};
export declare type CertificateControllerGetAggregateCertifiedEnergyByDeviceIdParams = {
    start: string;
    end: string;
};
export declare type IrecCertificateControllerGetAggregateCertifiedEnergyByDeviceIdParams = {
    start: string;
    end: string;
};
